@@ -404,7 +404,7 @@ class Graph(BaseGraph):
         if self.title:
             for i, title_line in enumerate(self.title, 1):
                 self.svg.node(
-                    self.nodes['title'], 'text', class_='title',
+                    self.nodes['title'], 'text', class_='title plot_title',
                     x=self.width / 2,
                     y=i * (self.title_font_size + self.spacing)
                 ).text = title_line
@@ -441,13 +441,16 @@ class Graph(BaseGraph):
         return dict(
             plot=self.svg.node(
                 self.nodes['plot'],
-                class_='series serie-%d color-%d' % (serie, serie % 16)),
+                class_='series serie-%d color-%d' % (
+                    serie, serie % len(self.style['colors']))),
             overlay=self.svg.node(
                 self.nodes['overlay'],
-                class_='series serie-%d color-%d' % (serie, serie % 16)),
+                class_='series serie-%d color-%d' % (
+                    serie, serie % len(self.style['colors']))),
             text_overlay=self.svg.node(
                 self.nodes['text_overlay'],
-                class_='series serie-%d color-%d' % (serie, serie % 16)))
+                class_='series serie-%d color-%d' % (
+                    serie, serie % len(self.style['colors']))))
 
     def _interpolate(self, xs, ys):
         """Make the interpolation"""
