@@ -68,7 +68,7 @@ class StackedBar(Bar):
         self._points(x_pos)
         y_pos = compute_scale(
             self._box.ymin, self._box.ymax, self.logarithmic, self.order_min
-        ) if not self.y_labels else map(float, self.y_labels)
+        ) if not self.y_labels else list(map(float, self.y_labels))
         self._x_ranges = zip(x_pos, x_pos[1:])
 
         self._x_labels = self.x_labels and list(zip(self.x_labels, [
